@@ -1,5 +1,5 @@
 /*******************************************************************************
-    Copyright (c) 2015 NVIDIA Corporation
+    Copyright (c) 2015-2019 NVIDIA Corporation
 
     Permission is hereby granted, free of charge, to any person obtaining a copy
     of this software and associated documentation files (the "Software"), to
@@ -80,6 +80,66 @@
         return ret;                                                          \
     }
 
+// Wrap an entry point into the UVM module.
+//
+// An entry function with signature
+//
+//    return_type foo(...);
+//
+// is required to have a counterpart of the form
+//
+//    return_type foo_entry(...) {
+//        UVM_ENTRY_RET(foo(...));
+//   }
+//
+// An entry function with signature
+//
+//    void foo(...);
+//
+// is required to have a counterpart of the form
+//
+//    void foo_entry(...) {
+//        UVM_ENTRY_VOID(foo(...));
+//   }
+//
+// Invocations of foo must be replaced by invocations of foo_entry at the entry
+// points.
+#define UVM_ENTRY_WRAP(line)                                                        \
+    do {                                                                            \
+        bool added;                                                                 \
+                                                                                    \
+        if (in_interrupt()) {                                                       \
+            line;                                                                   \
+        }                                                                           \
+        else if (uvm_thread_context_wrapper_is_used()) {                            \
+            uvm_thread_context_wrapper_t thread_context_wrapper;                    \
+                                                                                    \
+            added = uvm_thread_context_add(&thread_context_wrapper.context);        \
+            line;                                                                   \
+            if (added)                                                              \
+                uvm_thread_context_remove(&thread_context_wrapper.context);         \
+        }                                                                           \
+        else {                                                                      \
+            uvm_thread_context_t thread_context;                                    \
+                                                                                    \
+            added = uvm_thread_context_add(&thread_context);                        \
+            line;                                                                   \
+            if (added)                                                              \
+                uvm_thread_context_remove(&thread_context);                         \
+        }                                                                           \
+    } while (0)                                                                     \
+
+// Wrapper for non-void functions
+#define UVM_ENTRY_RET(func_call)               \
+    do {                                       \
+        typeof(func_call) ret;                 \
+        UVM_ENTRY_WRAP((ret = (func_call)));   \
+        return ret;                            \
+    } while (0)                                \
+
+// Wrapper for void functions
+#define UVM_ENTRY_VOID UVM_ENTRY_WRAP
+
 // Validate input ranges from the user with specific alignment requirement
 static bool uvm_api_range_invalid_aligned(NvU64 base, NvU64 length, NvU64 alignment)
 {
@@ -119,7 +179,6 @@ bool uvm_is_valid_vma_range(NvU64 start, NvU64 length);
 //          va_space->lock must be locked in shared or exclusive modes
 NV_STATUS uvm_api_range_type_check(uvm_va_space_t *va_space, NvU64 base, NvU64 length);
 
-NV_STATUS uvm_api_is_8_supported(UVM_IS_8_SUPPORTED_PARAMS *params, struct file *filp);
 NV_STATUS uvm_api_pageable_mem_access(UVM_PAGEABLE_MEM_ACCESS_PARAMS *params, struct file *filp);
 NV_STATUS uvm_api_pageable_mem_access_on_gpu(UVM_PAGEABLE_MEM_ACCESS_ON_GPU_PARAMS *params, struct file *filp);
 NV_STATUS uvm_api_register_gpu(UVM_REGISTER_GPU_PARAMS *params, struct file *filp);
