@@ -398,7 +398,7 @@ NV_STATUS uvm_gpu_init_access_counters(uvm_gpu_t *gpu)
     uvm_assert_mutex_locked(&g_uvm_global.global_lock);
     UVM_ASSERT(gpu->access_counter_buffer_hal != NULL);
 
-    status = uvm_rm_locked_call(nvUvmInterfaceInitAccessCntrInfo(gpu->rm_address_space,
+    status = uvm_rm_locked_call(nvUvmInterfaceInitAccessCntrInfo(gpu->rm_device,
                                                                  &access_counters->rm_info));
     if (status != NV_OK) {
         UVM_ERR_PRINT("Failed to init notify buffer info from RM: %s, GPU %s\n",
@@ -487,7 +487,7 @@ void uvm_gpu_deinit_access_counters(uvm_gpu_t *gpu)
     UVM_ASSERT(gpu->isr.access_counters.handling_ref_count == 0);
 
     if (access_counters->rm_info.accessCntrBufferHandle) {
-        NV_STATUS status = uvm_rm_locked_call(nvUvmInterfaceDestroyAccessCntrInfo(gpu->rm_address_space,
+        NV_STATUS status = uvm_rm_locked_call(nvUvmInterfaceDestroyAccessCntrInfo(gpu->rm_device,
                                                                                   &access_counters->rm_info));
         UVM_ASSERT(status == NV_OK);
 
@@ -510,7 +510,7 @@ bool uvm_gpu_access_counters_required(const uvm_gpu_t *gpu)
     if (!gpu->access_counters_supported)
         return false;
 
-    if (gpu->is_simulated)
+    if (gpu->rm_info.isSimulated)
         return true;
 
     return is_migration_enabled(UVM_ACCESS_COUNTER_TYPE_MIMC) || is_migration_enabled(UVM_ACCESS_COUNTER_TYPE_MOMC);
@@ -527,7 +527,7 @@ static NV_STATUS access_counters_take_ownership(uvm_gpu_t *gpu, UvmGpuAccessCntr
     UVM_ASSERT(gpu->access_counters_supported);
     UVM_ASSERT(mutex_is_locked(&gpu->isr.access_counters.service_lock.m));
 
-    status = uvm_rm_locked_call(nvUvmInterfaceEnableAccessCntr(gpu->rm_address_space,
+    status = uvm_rm_locked_call(nvUvmInterfaceEnableAccessCntr(gpu->rm_device,
                                                                &access_counters->rm_info,
                                                                config));
     if (status != NV_OK) {
@@ -558,7 +558,7 @@ static NV_STATUS access_counters_take_ownership(uvm_gpu_t *gpu, UvmGpuAccessCntr
     return NV_OK;
 
 error:
-    disable_status = uvm_rm_locked_call(nvUvmInterfaceDisableAccessCntr(gpu->rm_address_space,
+    disable_status = uvm_rm_locked_call(nvUvmInterfaceDisableAccessCntr(gpu->rm_device,
                                                                         &access_counters->rm_info));
     UVM_ASSERT(disable_status == NV_OK);
 
@@ -580,7 +580,7 @@ static void access_counters_yield_ownership(uvm_gpu_t *gpu)
     if (status != NV_OK)
         UVM_ASSERT(status == uvm_global_get_status());
 
-    status = uvm_rm_locked_call(nvUvmInterfaceDisableAccessCntr(gpu->rm_address_space,
+    status = uvm_rm_locked_call(nvUvmInterfaceDisableAccessCntr(gpu->rm_device,
                                                                 &access_counters->rm_info));
     UVM_ASSERT(status == NV_OK);
 }
@@ -773,7 +773,8 @@ static int cmp_sort_phys_notifications_by_processor_id(const void *_a, const voi
     UVM_ASSERT(!a->address.is_virtual);
     UVM_ASSERT(!b->address.is_virtual);
 
-    return UVM_CMP_DEFAULT(a->physical_info.resident_id, b->physical_info.resident_id);
+    return UVM_CMP_DEFAULT(uvm_id_value(a->physical_info.resident_id),
+                           uvm_id_value(b->physical_info.resident_id));
 }
 
 typedef enum
@@ -878,9 +879,9 @@ static NvU32 fetch_access_counter_buffer_entries(uvm_gpu_t *gpu,
             }
 
             if (current_entry->counter_type == UVM_ACCESS_COUNTER_TYPE_MOMC)
-                UVM_ASSERT(current_entry->physical_info.resident_id == gpu->id);
+                UVM_ASSERT(uvm_id_equal(current_entry->physical_info.resident_id, gpu->id));
             else
-                UVM_ASSERT(current_entry->physical_info.resident_id != gpu->id);
+                UVM_ASSERT(!uvm_id_equal(current_entry->physical_info.resident_id, gpu->id));
         }
 
         ++notification_index;
@@ -1065,9 +1066,9 @@ static NV_STATUS service_va_block_locked(uvm_processor_id_t processor,
                                                       &read_duplicate);
 
         if (!uvm_processor_mask_test_and_set(&service_context->resident_processors, new_residency))
-            uvm_page_mask_zero(&service_context->per_processor_masks[new_residency].new_residency);
+            uvm_page_mask_zero(&service_context->per_processor_masks[uvm_id_value(new_residency)].new_residency);
 
-        uvm_page_mask_set(&service_context->per_processor_masks[new_residency].new_residency, page_index);
+        uvm_page_mask_set(&service_context->per_processor_masks[uvm_id_value(new_residency)].new_residency, page_index);
 
         if (page_index < first_page_index)
             first_page_index = page_index;
@@ -1093,8 +1094,8 @@ static NV_STATUS service_va_block_locked(uvm_processor_id_t processor,
             uvm_page_mask_t *residency_mask = uvm_va_block_resident_mask_get(va_block, id);
             UVM_ASSERT(residency_mask);
 
-            migrate_pages = uvm_page_mask_andnot(&service_context->per_processor_masks[id].new_residency,
-                                                 &service_context->per_processor_masks[id].new_residency,
+            migrate_pages = uvm_page_mask_andnot(&service_context->per_processor_masks[uvm_id_value(id)].new_residency,
+                                                 &service_context->per_processor_masks[uvm_id_value(id)].new_residency,
                                                  residency_mask);
 
             if (!migrate_pages)
@@ -1156,7 +1157,7 @@ static NV_STATUS service_phys_single_va_block(uvm_gpu_t *gpu,
     uvm_va_space_mm_t *va_space_mm = NULL;
     NV_STATUS status = NV_OK;
     const uvm_processor_id_t processor = current_entry->counter_type == UVM_ACCESS_COUNTER_TYPE_MIMC?
-                                             gpu->id: UVM_CPU_ID;
+                                             gpu->id: UVM_ID_CPU;
 
     *clear_counter = false;
 
@@ -1189,10 +1190,10 @@ static NV_STATUS service_phys_single_va_block(uvm_gpu_t *gpu,
             goto done;
 
         va_space_access_counters = va_space_access_counters_info_get(va_space);
-        if (processor == UVM_CPU_ID && !atomic_read(&va_space_access_counters->params.enable_momc_migrations))
+        if (UVM_ID_IS_CPU(processor) && !atomic_read(&va_space_access_counters->params.enable_momc_migrations))
             goto done;
 
-        if (processor != UVM_CPU_ID && !atomic_read(&va_space_access_counters->params.enable_mimc_migrations))
+        if (!UVM_ID_IS_CPU(processor) && !atomic_read(&va_space_access_counters->params.enable_mimc_migrations))
             goto done;
 
         service_context->operation = UVM_SERVICE_OPERATION_ACCESS_COUNTERS;
@@ -1385,8 +1386,8 @@ static NV_STATUS service_phys_notification(uvm_gpu_t *gpu,
     if (config->rm.granularity == UVM_ACCESS_COUNTER_GRANULARITY_64K)
         sub_granularity = 1;
 
-    if (current_entry->physical_info.resident_id != UVM_CPU_ID) {
-        resident_gpu = uvm_gpu_get(current_entry->physical_info.resident_id);
+    if (UVM_ID_IS_GPU(current_entry->physical_info.resident_id)) {
+        resident_gpu = uvm_gpu_get_by_processor_id(current_entry->physical_info.resident_id);
         UVM_ASSERT(resident_gpu != NULL);
 
         if (gpu != resident_gpu && uvm_gpus_are_nvswitch_connected(gpu, resident_gpu)) {
@@ -1398,7 +1399,7 @@ static NV_STATUS service_phys_notification(uvm_gpu_t *gpu,
         // coherent NVLINK mappings. This can trigger notifications that
         // fall outside of the allocatable address range. We just drop
         // them.
-        if (address >= resident_gpu->vidmem_max_allocatable_address)
+        if (address >= resident_gpu->mem_info.max_allocatable_address)
             return NV_OK;
     }
 
@@ -1450,7 +1451,7 @@ static NV_STATUS service_phys_notifications(uvm_gpu_t *gpu,
         NV_STATUS status;
         uvm_access_counter_buffer_entry_t *current_entry = batch_context->phys.notifications[i];
 
-        if (current_entry->physical_info.resident_id == UVM_MAX_PROCESSORS)
+        if (!UVM_ID_IS_VALID(current_entry->physical_info.resident_id))
             continue;
 
         status = service_phys_notification(gpu, batch_context, current_entry);
