@@ -1,5 +1,5 @@
 /*******************************************************************************
-    Copyright (c) 2015-2018 NVIDIA Corporation
+    Copyright (c) 2015-2019 NVIDIA Corporation
 
     Permission is hereby granted, free of charge, to any person obtaining a copy
     of this software and associated documentation files (the "Software"), to
@@ -440,35 +440,35 @@ NV_STATUS uvm_hal_init_table(void)
 
 NV_STATUS uvm_hal_init_gpu(uvm_gpu_t *gpu)
 {
-    uvm_hal_class_ops_t *class_ops = ops_find_by_id(ce_table, ARRAY_SIZE(ce_table), gpu->ce_class);
+    uvm_hal_class_ops_t *class_ops = ops_find_by_id(ce_table, ARRAY_SIZE(ce_table), gpu->rm_info.ceClass);
     if (class_ops == NULL) {
-        UVM_ERR_PRINT("Unsupported ce class: 0x%X, GPU %s\n", gpu->ce_class, gpu->name);
+        UVM_ERR_PRINT("Unsupported ce class: 0x%X, GPU %s\n", gpu->rm_info.ceClass, gpu->name);
         return NV_ERR_INVALID_CLASS;
     }
 
     gpu->ce_hal = &class_ops->u.ce_ops;
 
-    class_ops = ops_find_by_id(host_table, ARRAY_SIZE(host_table), gpu->host_class);
+    class_ops = ops_find_by_id(host_table, ARRAY_SIZE(host_table), gpu->rm_info.hostClass);
     if (class_ops == NULL) {
-        UVM_ERR_PRINT("Unsupported host class: 0x%X, GPU %s\n", gpu->host_class, gpu->name);
+        UVM_ERR_PRINT("Unsupported host class: 0x%X, GPU %s\n", gpu->rm_info.hostClass, gpu->name);
         return NV_ERR_INVALID_CLASS;
     }
 
     gpu->host_hal = &class_ops->u.host_ops;
 
-    class_ops = ops_find_by_id(arch_table, ARRAY_SIZE(arch_table), gpu->architecture);
+    class_ops = ops_find_by_id(arch_table, ARRAY_SIZE(arch_table), gpu->rm_info.gpuArch);
     if (class_ops == NULL) {
-        UVM_ERR_PRINT("Unsupported GPU architecture: 0x%X, GPU %s\n", gpu->architecture, gpu->name);
+        UVM_ERR_PRINT("Unsupported GPU architecture: 0x%X, GPU %s\n", gpu->rm_info.gpuArch, gpu->name);
         return NV_ERR_INVALID_CLASS;
     }
 
     gpu->arch_hal = &class_ops->u.arch_ops;
 
     // Initialize the fault buffer hal only for GPUs supporting faults (with non-0 fault buffer class).
-    if (gpu->fault_buffer_class != 0) {
-        class_ops = ops_find_by_id(fault_buffer_table, ARRAY_SIZE(fault_buffer_table), gpu->fault_buffer_class);
+    if (gpu->rm_info.faultBufferClass != 0) {
+        class_ops = ops_find_by_id(fault_buffer_table, ARRAY_SIZE(fault_buffer_table), gpu->rm_info.faultBufferClass);
         if (class_ops == NULL) {
-            UVM_ERR_PRINT("Unsupported fault buffer class: 0x%X, GPU %s\n", gpu->fault_buffer_class, gpu->name);
+            UVM_ERR_PRINT("Unsupported fault buffer class: 0x%X, GPU %s\n", gpu->rm_info.faultBufferClass, gpu->name);
             return NV_ERR_INVALID_CLASS;
         }
         gpu->fault_buffer_hal = &class_ops->u.fault_buffer_ops;
@@ -479,13 +479,13 @@ NV_STATUS uvm_hal_init_gpu(uvm_gpu_t *gpu)
 
     // Initialize the access counter buffer hal only for GPUs supporting access counters (with non-0 access counter
     // buffer class).
-    if (gpu->access_counter_buffer_class != 0) {
+    if (gpu->rm_info.accessCounterBufferClass != 0) {
         class_ops = ops_find_by_id(access_counter_buffer_table,
                                    ARRAY_SIZE(access_counter_buffer_table),
-                                   gpu->access_counter_buffer_class);
+                                   gpu->rm_info.accessCounterBufferClass);
         if (class_ops == NULL) {
             UVM_ERR_PRINT("Unsupported access counter buffer class: 0x%X, GPU %s\n",
-                          gpu->access_counter_buffer_class,
+                          gpu->rm_info.accessCounterBufferClass,
                           gpu->name);
             return NV_ERR_INVALID_CLASS;
         }
