@@ -1,5 +1,5 @@
 /*******************************************************************************
-    Copyright (c) 2015 NVIDIA Corporation
+    Copyright (c) 2015-2019 NVIDIA Corporation
 
     Permission is hereby granted, free of charge, to any person obtaining a copy
     of this software and associated documentation files (the "Software"), to
@@ -139,7 +139,7 @@ static uvm_va_range_t *uvm_va_range_alloc_managed(uvm_va_space_t *va_space, NvU6
     va_range->type = UVM_VA_RANGE_TYPE_MANAGED;
 
     va_range->read_duplication = UVM_READ_DUPLICATION_UNSET;
-    va_range->preferred_location = UVM_MAX_PROCESSORS;
+    va_range->preferred_location = UVM_ID_INVALID;
 
     va_range->blocks = uvm_kvmalloc_zero(uvm_va_range_num_blocks(va_range) * sizeof(va_range->blocks[0]));
     if (!va_range->blocks) {
@@ -292,6 +292,7 @@ NV_STATUS uvm_va_range_create_semaphore_pool(uvm_va_space_t *va_space,
     uvm_va_range_t *va_range = NULL;
     uvm_mem_alloc_params_t mem_alloc_params = { 0 };
     NvU32 i;
+    uvm_gpu_id_t gpu_id;
 
     va_range = uvm_va_range_alloc(va_space, start, start + length - 1);
     if (!va_range) {
@@ -317,8 +318,10 @@ NV_STATUS uvm_va_range_create_semaphore_pool(uvm_va_space_t *va_space,
 
     va_range->semaphore_pool.default_gpu_attrs = default_attrs;
     va_range->semaphore_pool.owner = NULL;
-    for (i = 0; i < UVM_MAX_GPUS; i++)
-        va_range->semaphore_pool.gpu_attrs[i] = default_attrs;
+
+    for_each_gpu_id(gpu_id)
+        va_range->semaphore_pool.gpu_attrs[uvm_id_gpu_index(gpu_id)] = default_attrs;
+
     for (i = 0; i < per_gpu_attrs_count; i++) {
         uvm_gpu_t *gpu;
         uvm_mem_gpu_mapping_attrs_t attrs = default_attrs;
@@ -334,7 +337,7 @@ NV_STATUS uvm_va_range_create_semaphore_pool(uvm_va_space_t *va_space,
             }
             va_range->semaphore_pool.owner = gpu;
         }
-        va_range->semaphore_pool.gpu_attrs[uvm_gpu_index(gpu->id)] = attrs;
+        va_range->semaphore_pool.gpu_attrs[uvm_id_gpu_index(gpu->id)] = attrs;
     }
 
     if (out_va_range)
@@ -352,6 +355,7 @@ static void uvm_va_range_destroy_managed(uvm_va_range_t *va_range)
     uvm_va_block_t *block;
     uvm_va_block_t *block_tmp;
     uvm_perf_event_data_t event_data;
+    NV_STATUS status;
 
     UVM_ASSERT(va_range->type == UVM_VA_RANGE_TYPE_MANAGED);
 
@@ -366,7 +370,8 @@ static void uvm_va_range_destroy_managed(uvm_va_range_t *va_range)
     event_data.range_destroy.range = va_range;
     uvm_perf_event_notify(&va_range->va_space->perf_events, UVM_PERF_EVENT_RANGE_DESTROY, &event_data);
 
-    uvm_range_group_assign_range(va_range->va_space, NULL, va_range->node.start, va_range->node.end);
+    status = uvm_range_group_assign_range(va_range->va_space, NULL, va_range->node.start, va_range->node.end);
+    UVM_ASSERT(status == NV_OK);
 }
 
 static void uvm_va_range_destroy_external(uvm_va_range_t *va_range, struct list_head *deferred_free_list)
@@ -378,7 +383,7 @@ static void uvm_va_range_destroy_external(uvm_va_range_t *va_range, struct list_
 
     UVM_ASSERT(deferred_free_list);
 
-    for_each_gpu_in_mask(gpu, &va_range->external.mapped_gpus)
+    for_each_va_space_gpu_in_mask(gpu, va_range->va_space, &va_range->external.mapped_gpus)
         uvm_ext_gpu_map_destroy(va_range, gpu, deferred_free_list);
 
     UVM_ASSERT(uvm_processor_mask_empty(&va_range->external.mapped_gpus));
@@ -428,8 +433,9 @@ static void uvm_va_range_destroy_semaphore_pool(uvm_va_range_t *va_range)
     NV_STATUS status = uvm_tracker_wait_deinit(&va_range->semaphore_pool.tracker);
     if (status != NV_OK) {
         UVM_ASSERT_MSG(status == uvm_global_get_status(),
-                "uvm_tracker_wait() returned %d (%s) in uvm_va_range_destroy_semaphore_pool()",
-                status, nvstatusToString(status));
+                       "uvm_tracker_wait() returned %d (%s) in uvm_va_range_destroy_semaphore_pool()\n",
+                       status,
+                       nvstatusToString(status));
     }
     uvm_mem_free(va_range->semaphore_pool.mem);
     va_range->semaphore_pool.mem = NULL;
@@ -591,7 +597,7 @@ NV_STATUS uvm_va_range_add_gpu_va_space(uvm_va_range_t *va_range, uvm_gpu_va_spa
         case UVM_VA_RANGE_TYPE_MANAGED:
             return uvm_va_range_add_gpu_va_space_managed(va_range, gpu_va_space);
         case UVM_VA_RANGE_TYPE_SEMAPHORE_POOL:
-            attrs = &va_range->semaphore_pool.gpu_attrs[uvm_gpu_index(gpu_va_space->gpu->id)];
+            attrs = &va_range->semaphore_pool.gpu_attrs[uvm_id_gpu_index(gpu_va_space->gpu->id)];
             return uvm_mem_map_gpu_user(va_range->semaphore_pool.mem, gpu_va_space->gpu, attrs);
         default:
             return NV_OK;
@@ -749,9 +755,9 @@ static void uvm_va_range_disable_peer_managed(uvm_va_range_t *va_range, uvm_gpu_
         // preferred location. If peer mappings are being disabled to the
         // preferred location, then unmap the other GPU.
         // Nothing to do otherwise.
-        if (va_range->preferred_location == gpu0->id)
+        if (uvm_id_equal(va_range->preferred_location, gpu0->id))
             uvm_lite_gpu_to_unmap = gpu1;
-        else if (va_range->preferred_location == gpu1->id)
+        else if (uvm_id_equal(va_range->preferred_location, gpu1->id))
             uvm_lite_gpu_to_unmap = gpu0;
         else
             return;
@@ -811,8 +817,8 @@ static void uvm_va_range_unregister_gpu_managed(uvm_va_range_t *va_range, uvm_gp
     // Reset preferred location and accessed-by of VA ranges if needed
     // Note: ignoring the return code of uvm_va_range_set_preferred_location since this
     // will only return on error when setting a preferred location, not on a reset
-    if (va_range->preferred_location == gpu->id)
-        (void)uvm_va_range_set_preferred_location(va_range, UVM_MAX_PROCESSORS);
+    if (uvm_id_equal(va_range->preferred_location, gpu->id))
+        (void)uvm_va_range_set_preferred_location(va_range, UVM_ID_INVALID);
 
     uvm_va_range_unset_accessed_by(va_range, gpu->id);
 
@@ -832,7 +838,7 @@ static void uvm_va_range_unregister_gpu_external(uvm_va_range_t *va_range,
     uvm_ext_gpu_map_t *ext_gpu_map;
     uvm_gpu_t *other_gpu;
 
-    for_each_gpu_in_mask(other_gpu, &va_range->external.mapped_gpus) {
+    for_each_va_space_gpu_in_mask(other_gpu, va_range->va_space, &va_range->external.mapped_gpus) {
         UVM_ASSERT(other_gpu != gpu);
 
         ext_gpu_map = uvm_va_range_ext_gpu_map(va_range, other_gpu);
@@ -851,7 +857,7 @@ static void uvm_va_range_unregister_gpu_semaphore_pool(uvm_va_range_t *va_range,
 
     // All ranges for this GPU should have been unmapped by GPU VA space
     // unregister, which should have already happened.
-    UVM_ASSERT(!uvm_processor_mask_test(&va_range->semaphore_pool.mem->mapped_on, gpu->id));
+    UVM_ASSERT(!uvm_global_processor_mask_test(&va_range->semaphore_pool.mem->mapped_on, gpu->global_id));
     uvm_mutex_lock(&va_range->semaphore_pool.tracker_lock);
     status = uvm_tracker_wait(&va_range->semaphore_pool.tracker);
     uvm_mutex_unlock(&va_range->semaphore_pool.tracker_lock);
@@ -860,7 +866,7 @@ static void uvm_va_range_unregister_gpu_semaphore_pool(uvm_va_range_t *va_range,
 
     uvm_mem_unmap_gpu_phys(va_range->semaphore_pool.mem, gpu);
 
-    va_range->semaphore_pool.gpu_attrs[uvm_gpu_index(gpu->id)] = va_range->semaphore_pool.default_gpu_attrs;
+    va_range->semaphore_pool.gpu_attrs[uvm_id_gpu_index(gpu->id)] = va_range->semaphore_pool.default_gpu_attrs;
     if (va_range->semaphore_pool.owner == gpu)
         va_range->semaphore_pool.owner = NULL;
 }
@@ -1244,13 +1250,15 @@ static void calc_uvm_lite_gpus_mask(uvm_va_space_t *va_space,
     uvm_processor_mask_zero(uvm_lite_gpus);
 
     // If no preferred location is set then there are no GPUs following the UVM-Lite behavior
-    if (preferred_location == UVM_MAX_PROCESSORS)
+    if (UVM_ID_IS_INVALID(preferred_location))
         return;
 
     // If the preferred location is a faultable GPU, then no GPUs should follow
     // the UVM-Lite behaviour.
-    if (preferred_location != UVM_CPU_ID && uvm_processor_mask_test(&va_space->faultable_processors, preferred_location))
+    if (UVM_ID_IS_GPU(preferred_location) &&
+        uvm_processor_mask_test(&va_space->faultable_processors, preferred_location)) {
         return;
+    }
 
     // Otherwise add all non-faultable GPUs to the UVM-Lite mask that have
     // accessed by set.
@@ -1260,7 +1268,7 @@ static void calc_uvm_lite_gpus_mask(uvm_va_space_t *va_space,
     }
 
     // And the preferred location if it's a GPU
-    if (preferred_location != UVM_CPU_ID)
+    if (UVM_ID_IS_GPU(preferred_location))
         uvm_processor_mask_set(uvm_lite_gpus, preferred_location);
 }
 
@@ -1289,7 +1297,7 @@ NV_STATUS uvm_va_range_set_preferred_location(uvm_va_range_t *va_range, uvm_proc
     uvm_assert_rwsem_locked_write(&va_space->lock);
     UVM_ASSERT(va_range->type == UVM_VA_RANGE_TYPE_MANAGED);
 
-    if (va_range->preferred_location == preferred_location)
+    if (uvm_id_equal(va_range->preferred_location, preferred_location))
         return NV_OK;
 
     // Mark all range group ranges within this VA range as migrated since the preferred location has changed.
@@ -1308,12 +1316,12 @@ NV_STATUS uvm_va_range_set_preferred_location(uvm_va_range_t *va_range, uvm_proc
     // If the range contains non-migratable range groups, check that new UVM-Lite GPUs
     // can all map the new preferred location.
     if (!uvm_range_group_all_migratable(va_space, va_range->node.start, va_range->node.end) &&
-        preferred_location != UVM_MAX_PROCESSORS &&
-        !uvm_processor_mask_subset(&new_uvm_lite_gpus,
-                                   &va_space->accessible_from[preferred_location]))
+        UVM_ID_IS_VALID(preferred_location) &&
+        !uvm_processor_mask_subset(&new_uvm_lite_gpus, &va_space->accessible_from[uvm_id_value(preferred_location)])) {
         return NV_ERR_INVALID_DEVICE;
+    }
 
-    if (preferred_location == UVM_MAX_PROCESSORS) {
+    if (UVM_ID_IS_INVALID(preferred_location)) {
         uvm_range_group_for_each_migratability_in_safe(&iter,
                                                        va_space,
                                                        va_range->node.start,
@@ -1345,12 +1353,12 @@ NV_STATUS uvm_va_range_set_preferred_location(uvm_va_range_t *va_range, uvm_proc
     // mode if it is the new preferred location. Otherwise we'd have to be more
     // careful below to not establish remote mappings to the new preferred
     // location.
-    if (preferred_location != UVM_MAX_PROCESSORS && preferred_location != UVM_CPU_ID)
+    if (UVM_ID_IS_GPU(preferred_location))
         UVM_ASSERT(!uvm_processor_mask_test(&set_accessed_by_processors, preferred_location));
 
     // The old preferred location should establish new remote mappings if it has
     // accessed-by set.
-    if (va_range->preferred_location < UVM_MAX_PROCESSORS)
+    if (UVM_ID_IS_VALID(va_range->preferred_location))
         uvm_processor_mask_set(&set_accessed_by_processors, va_range->preferred_location);
 
     uvm_processor_mask_and(&set_accessed_by_processors, &set_accessed_by_processors, &va_range->accessed_by);
@@ -1394,9 +1402,9 @@ NV_STATUS uvm_va_range_set_accessed_by(uvm_va_range_t *va_range, uvm_processor_i
     // If the range belongs to a non-migratable range group and that processor_id is a non-faultable GPU,
     // check it can map the preferred location
     if (!uvm_range_group_all_migratable(va_space, va_range->node.start, va_range->node.end) &&
-        processor_id != UVM_CPU_ID &&
+        UVM_ID_IS_GPU(processor_id) &&
         !uvm_processor_mask_test(&va_space->faultable_processors, processor_id) &&
-        !uvm_processor_mask_test(&va_space->accessible_from[va_range->preferred_location], processor_id))
+        !uvm_processor_mask_test(&va_space->accessible_from[uvm_id_value(va_range->preferred_location)], processor_id))
         return NV_ERR_INVALID_DEVICE;
 
     uvm_processor_mask_set(&va_range->accessed_by, processor_id);
@@ -1451,8 +1459,10 @@ void uvm_va_range_unset_accessed_by(uvm_va_range_t *va_range, uvm_processor_id_t
 
     // If a UVM-Lite GPU is being removed from the accessed_by mask, it will
     // also stop being a UVM-Lite GPU unless it's also the preferred location.
-    if (uvm_processor_mask_test(&va_range->uvm_lite_gpus, processor_id) && va_range->preferred_location != processor_id)
+    if (uvm_processor_mask_test(&va_range->uvm_lite_gpus, processor_id) &&
+        !uvm_id_equal(va_range->preferred_location, processor_id)) {
         range_unmap(va_range, processor_id);
+    }
 
     range_update_uvm_lite_gpus_mask(va_range);
 }
@@ -1606,7 +1616,7 @@ NV_STATUS uvm_va_range_check_logical_permissions(uvm_va_range_t *va_range,
     // TODO: Bug 1766124: permissions are checked by block_map_cpu_page because
     //       it can also be called from change_pte. Make change_pte call this
     //       function and only check CPU permissions here.
-    if (processor_id != UVM_CPU_ID) {
+    if (UVM_ID_IS_GPU(processor_id)) {
         // Zombified VA ranges no longer have a vma, so they have no permissions
         if (uvm_va_range_is_managed_zombie(va_range))
             return NV_ERR_INVALID_ADDRESS;
@@ -1627,11 +1637,15 @@ NV_STATUS uvm_va_range_check_logical_permissions(uvm_va_range_t *va_range,
     // - CPU accesses are always fatal, regardless of the VA range residency
     // - GPU accesses are fatal if the GPU can't map the preferred location
     if (!allow_migration) {
-        if (processor_id == UVM_CPU_ID)
+        if (UVM_ID_IS_CPU(processor_id)) {
             return NV_ERR_INVALID_OPERATION;
-        else
-            return uvm_processor_mask_test(&va_range->va_space->accessible_from[va_range->preferred_location],
-                                           processor_id) ? NV_OK : NV_ERR_INVALID_ACCESS_TYPE;
+        }
+        else {
+            return uvm_processor_mask_test(
+                    &va_range->va_space->accessible_from[uvm_id_value(va_range->preferred_location)],
+                    processor_id)?
+                NV_OK : NV_ERR_INVALID_ACCESS_TYPE;
+        }
     }
 
     return NV_OK;
@@ -1677,7 +1691,7 @@ static NV_STATUS uvm_map_sked_reflected_range(uvm_va_space_t *va_space, UVM_MAP_
         goto done;
     }
 
-    gpu_va_space = va_space->gpu_va_spaces[uvm_gpu_index(gpu->id)];
+    gpu_va_space = va_space->gpu_va_spaces[uvm_id_gpu_index(gpu->id)];
     page_tables = &gpu_va_space->page_tables;
 
     // The VA range must exactly cover one supported GPU page
@@ -1756,8 +1770,8 @@ NV_STATUS uvm_api_alloc_semaphore_pool(UVM_ALLOC_SEMAPHORE_POOL_PARAMS *params,
         return status;
     }
 
-    for_each_gpu_in_mask(gpu, &va_space->registered_gpu_va_spaces) {
-        attrs = &va_range->semaphore_pool.gpu_attrs[uvm_gpu_index(gpu->id)];
+    for_each_va_space_gpu_in_mask(gpu, va_space, &va_space->registered_gpu_va_spaces) {
+        attrs = &va_range->semaphore_pool.gpu_attrs[uvm_id_gpu_index(gpu->id)];
         status = uvm_mem_map_gpu_user(va_range->semaphore_pool.mem, gpu, attrs);
         if (status != NV_OK)
             goto done;
@@ -1799,14 +1813,14 @@ NV_STATUS uvm8_test_va_range_info(UVM_TEST_VA_RANGE_INFO_PARAMS *params, struct
     BUILD_BUG_ON((int)UVM_READ_DUPLICATION_MAX      != (int)UVM_TEST_READ_DUPLICATION_MAX);
     params->read_duplication = va_range->read_duplication;
 
-    if (va_range->preferred_location == UVM_MAX_PROCESSORS)
+    if (UVM_ID_IS_INVALID(va_range->preferred_location))
         memset(&params->preferred_location, 0, sizeof(params->preferred_location));
     else
-        uvm_processor_uuid_from_id(&params->preferred_location, va_range->preferred_location);
+        uvm_va_space_processor_uuid(va_space, &params->preferred_location, va_range->preferred_location);
 
     params->accessed_by_count = 0;
     for_each_id_in_mask(processor_id, &va_range->accessed_by)
-        uvm_processor_uuid_from_id(&params->accessed_by[params->accessed_by_count++], processor_id);
+        uvm_va_space_processor_uuid(va_space, &params->accessed_by[params->accessed_by_count++], processor_id);
 
     // -Wall implies -Wenum-compare, so cast through int to avoid warnings
     BUILD_BUG_ON((int)UVM_TEST_VA_RANGE_TYPE_INVALID        != (int)UVM_VA_RANGE_TYPE_INVALID);
