@@ -1,5 +1,5 @@
 /*******************************************************************************
-    Copyright (c) 2015 NVIDIA Corporation
+    Copyright (c) 2015-2019 NVIDIA Corporation
 
     Permission is hereby granted, free of charge, to any person obtaining a copy
     of this software and associated documentation files (the "Software"), to
@@ -59,7 +59,7 @@
 // location preferences) must take the lock in write mode.
 //
 // VA ranges with type == UVM_VA_RANGE_TYPE_MANAGED:
-//     Each va_range is contained completely with a parent vma. There can be
+//     Each va_range is contained completely within a parent vma. There can be
 //     multiple va_ranges under the same vma, but not vice versa. All VAs within
 //     the va_range share the same policy state.
 //
@@ -198,7 +198,7 @@ typedef struct
     // Per-GPU external mapping state. This has to be per-GPU in the VA range
     // because each GPU is able to map a completely different allocation to the
     // same VA range.
-    uvm_ext_gpu_map_t *gpu_maps[UVM_MAX_GPUS];
+    uvm_ext_gpu_map_t *gpu_maps[UVM_ID_MAX_GPUS];
 
 } uvm_va_range_external_t;
 
@@ -263,7 +263,7 @@ typedef struct
     uvm_gpu_t *owner;
 
     // Per-gpu attributes
-    uvm_mem_gpu_mapping_attrs_t gpu_attrs[UVM_MAX_GPUS];
+    uvm_mem_gpu_mapping_attrs_t gpu_attrs[UVM_ID_MAX_GPUS];
 
     // Default attributes to assign when a new GPU is registered
     uvm_mem_gpu_mapping_attrs_t default_gpu_attrs;
@@ -286,6 +286,7 @@ struct uvm_va_range_struct
     nv_kref_t kref;
 
     // Storage in VA range tree. Also contains range start and end.
+    // start and end + 1 have to be PAGE_SIZED aligned.
     uvm_range_tree_node_t node;
 
     // Force the next split on this range to fail. Set by error injection ioctl
@@ -295,8 +296,8 @@ struct uvm_va_range_struct
     // Read duplication policy of this VA range (unset, enabled or disabled)
     uvm_read_duplication_policy_t read_duplication;
 
-    // Processor ID of the preferred location of this VA range.
-    // This is set to UVM_MAX_PROCESSORS if no preferred location is set
+    // Processor ID of the preferred location of this VA range. This is set to
+    // UVM_ID_INVALID if no preferred location is set
     uvm_processor_id_t preferred_location;
 
     // Mask of processors that are accessing this VA range
@@ -317,7 +318,7 @@ struct uvm_va_range_struct
     // This is a uvm_va_block_t ** array of all VA block pointers under this
     // range. The pointers can be accessed using the functions
     // uvm_va_range_block() and uvm_va_range_block_create(). The latter
-    // allocates the block if it doesn't already exist. Once allocated the
+    // allocates the block if it doesn't already exist. Once allocated, the
     // blocks persist in the array until the parent VA range is destroyed.
     //
     // Concurrent on-demand allocation requires the use of either atomics or a
@@ -605,7 +606,7 @@ static struct vm_area_struct *uvm_va_range_vma(uvm_va_range_t *va_range)
                    "vma: 0x%llx [0x%lx, 0x%lx] has vm_private_data 0x%llx\n",
                    (NvU64)vma,
                    vma->vm_start,
-                   vma->vm_end-1,
+                   vma->vm_end - 1,
                    (NvU64)vma->vm_private_data);
     UVM_ASSERT_MSG(va_range->va_space == uvm_va_space_get(vma->vm_file),
                    "va_range va_space: 0x%llx vm_file: 0x%llx vm_file va_space: 0x%llx",
@@ -617,13 +618,13 @@ static struct vm_area_struct *uvm_va_range_vma(uvm_va_range_t *va_range)
                    va_range->node.start,
                    va_range->node.end,
                    vma->vm_start,
-                   vma->vm_end-1);
+                   vma->vm_end - 1);
     UVM_ASSERT_MSG(va_range->node.end <= vma->vm_end - 1,
                    "Range mismatch: va_range: [0x%llx, 0x%llx] vma: [0x%lx, 0x%lx]\n",
                    va_range->node.start,
                    va_range->node.end,
                    vma->vm_start,
-                   vma->vm_end-1);
+                   vma->vm_end - 1);
 
     return vma;
 }
@@ -635,7 +636,7 @@ static struct vm_area_struct *uvm_va_range_vma_check(uvm_va_range_t *va_range, s
 {
     struct vm_area_struct *vma;
 
-    UVM_ASSERT_MSG(va_range->type == UVM_VA_RANGE_TYPE_MANAGED, "type: %d", va_range->type);
+    UVM_ASSERT_MSG(va_range->type == UVM_VA_RANGE_TYPE_MANAGED, "type: %d\n", va_range->type);
 
     // Zombies don't have a vma_wrapper.
     if (!va_range->managed.vma_wrapper)
@@ -694,7 +695,7 @@ static uvm_ext_gpu_map_t *uvm_va_range_ext_gpu_map(uvm_va_range_t *va_range, uvm
     UVM_ASSERT(va_range->type == UVM_VA_RANGE_TYPE_EXTERNAL);
     uvm_assert_rwsem_locked(&va_range->va_space->lock);
 
-    ext_gpu_map = va_range->external.gpu_maps[mapping_gpu->id - 1];
+    ext_gpu_map = va_range->external.gpu_maps[uvm_id_gpu_index(mapping_gpu->id)];
     if (ext_gpu_map) {
         UVM_ASSERT(uvm_processor_mask_test(&va_range->external.mapped_gpus, mapping_gpu->id));
         UVM_ASSERT(ext_gpu_map->gpu == mapping_gpu);
@@ -770,14 +771,14 @@ uvm_va_block_t *uvm_va_range_block_next(uvm_va_range_t *va_range, uvm_va_block_t
          __va_block_next = __va_block? uvm_va_range_block_next(__va_range, __va_block) : NULL)
 
 // Set the VA range preferred location (or unset it if preferred location is
-// UVM_MAX_PROCESSORS).
+// UVM_ID_INVALID).
 //
 // Unsetting the preferred location potentially changes the range group
 // association to UVM_RANGE_GROUP_ID_NONE if the VA range was previously
 // associated with a non-migratable range group.
 //
-// Changing the preferred location also updates the mask and mappings of GPUs in
-// UVM-Lite mode.
+// Changing the preferred location also updates the mask and mappings of GPUs
+// in UVM-Lite mode.
 //
 // The va_range must have type UVM_VA_RANGE_TYPE_MANAGED.
 NV_STATUS uvm_va_range_set_preferred_location(uvm_va_range_t *va_range, uvm_processor_id_t preferred_location);
